# 高效碳基演示机体系基础包  
gTixi适用于高效碳基芯片测试的函数库  
由魏楠和李若铭开发
## 功能介绍
该模块包含了树莓派，掌控板，未来版，未名系列演示机的通用演示架构。可以使用一套代码，兼容地运行在不同地设备上。

## 版本介绍  
- 0.0.4
  - 221205
  - 将目前硬件的驱动也并入gTixi中，包括加法器，蜂鸣器，红外，bme，光线传感器
  - 修改loopMod的逻辑，修正在暂停状态下不能停止的bug
- 0.0.3 
  - 221203
  - 相对稳定的初始测试版本，使用相对import引入，使架构更加科学
- 0.0.2
  - 221202
  - 去除了部分alib的内容改为字典或者临时类，避免了zkb的无限重启的问题
- 0.0.1
  - 221202
  - 初始版本发布